pub struct GlobalConfig {
pub measurements: Option<MeasurementsConfig>,
pub quotas: Vec<Quota>,
pub filters: ErrorBoundary<GenericFiltersConfig>,
pub options: Options,
pub metric_extraction: ErrorBoundary<MetricExtractionGroups>,
pub ai_model_costs: ErrorBoundary<ModelCosts>,
pub ai_model_metadata: ErrorBoundary<ModelMetadata>,
pub span_op_defaults: SpanOpDefaults,
}Expand description
A dynamic configuration for all Relays passed down from Sentry.
Values shared across all projects may also be included here, to keep
ProjectConfigs small.
Fields
measurements: Option<MeasurementsConfig>Configuration for measurements normalization.
quotas: Vec<Quota>Quotas that apply to all projects.
filters: ErrorBoundary<GenericFiltersConfig>Configuration for global inbound filters.
These filters are merged with generic filters in project configs before applying.
options: OptionsSentry options passed down to Relay.
metric_extraction: ErrorBoundary<MetricExtractionGroups>Configuration for global metrics extraction rules.
These are merged with rules in project configs before applying.
ai_model_costs: ErrorBoundary<ModelCosts>Configuration for AI span measurements.
ai_model_metadata: ErrorBoundary<ModelMetadata>Metadata for AI models including costs and context size.
span_op_defaults: SpanOpDefaultsConfiguration to derive the span.op from other span fields.
Implementations
Sourceimpl GlobalConfig
impl GlobalConfig
Sourcepub fn load(folder_path: &Path) -> Result<Option<Self>>
pub fn load(folder_path: &Path) -> Result<Option<Self>>
Loads the GlobalConfig from a file if it’s provided.
The folder_path argument should be the path to the folder where the Relay config and credentials are stored.
Sourcepub fn model_metadata(&self) -> Option<ModelMetadata>
pub fn model_metadata(&self) -> Option<ModelMetadata>
Returns [ModelMetadata], preferring ai_model_metadata if present and falling
back to ai_model_costs (adapted to the new format) otherwise.