pub struct Options {
pub cardinality_limiter_mode: CardinalityLimiterMode,
pub cardinality_limiter_error_sample_rate: f32,
pub metric_bucket_set_encodings: BucketEncodings,
pub metric_bucket_dist_encodings: BucketEncodings,
pub http_span_allowed_hosts: Vec<String>,
pub objectstore_attachments_sample_rate: f32,
pub sessions_eap_rollout_rate: f32,
pub eap_outcomes_rollout_rate: f32,
pub eap_span_outcomes_rollout_rate: f32,
/* private fields */
}Expand description
All options passed down from Sentry to Relay.
Fields
cardinality_limiter_mode: CardinalityLimiterModeKill switch for controlling the cardinality limiter.
cardinality_limiter_error_sample_rate: f32Sample rate for Cardinality Limiter Sentry errors.
Rate needs to be between 0.0 and 1.0.
If set to 1.0 all cardinality limiter rejections will be logged as a Sentry error.
metric_bucket_set_encodings: BucketEncodingsMetric bucket encoding configuration for sets by metric namespace.
metric_bucket_dist_encodings: BucketEncodingsMetric bucket encoding configuration for distributions by metric namespace.
http_span_allowed_hosts: Vec<String>List of values on span description that are allowed to be sent to Sentry without being scrubbed.
At this point, it doesn’t accept IP addresses in CIDR format.. yet.
objectstore_attachments_sample_rate: f32Instructs relay to store attachments in objectstore instead of sending chunks via kafka.
Rate needs to be between 0.0 and 1.0.
If set to 1.0 all attachments will be stored in objectstore.
sessions_eap_rollout_rate: f32Rollout rate for the EAP (Event Analytics Platform) double-write for user sessions.
When rolled out, session data is sent both through the legacy metrics pipeline
and directly to the snuba-items topic as TRACE_ITEM_TYPE_USER_SESSION.
Rate needs to be between 0.0 and 1.0.
eap_outcomes_rollout_rate: f32Rollout rate for accepted outcomes being emitted by EAP instead of Relay.
Rate needs to be between 0.0 and 1.0.
eap_span_outcomes_rollout_rate: f32Rollout rate for accepted outcomes for spans being emitted by EAP instead of Relay.
Rate needs to be between 0.0 and 1.0.