pub struct GlobalConfig {
pub measurements: Option<MeasurementsConfig>,
pub quotas: Vec<Quota>,
pub filters: ErrorBoundary<GenericFiltersConfig>,
pub options: Options,
pub metric_extraction: ErrorBoundary<MetricExtractionGroups>,
pub ai_model_costs: ErrorBoundary<ModelCosts>,
pub span_op_defaults: SpanOpDefaults,
}Expand description
A dynamic configuration for all Relays passed down from Sentry.
Values shared across all projects may also be included here, to keep
ProjectConfigs small.
Fields
measurements: Option<MeasurementsConfig>Configuration for measurements normalization.
quotas: Vec<Quota>Quotas that apply to all projects.
filters: ErrorBoundary<GenericFiltersConfig>Configuration for global inbound filters.
These filters are merged with generic filters in project configs before applying.
options: OptionsSentry options passed down to Relay.
metric_extraction: ErrorBoundary<MetricExtractionGroups>Configuration for global metrics extraction rules.
These are merged with rules in project configs before applying.
ai_model_costs: ErrorBoundary<ModelCosts>Configuration for AI span measurements.
span_op_defaults: SpanOpDefaultsConfiguration to derive the span.op from other span fields.
Implementations
Sourceimpl GlobalConfig
impl GlobalConfig