pub struct ProjectConfig {Show 23 fields
pub allowed_domains: Vec<String>,
pub trusted_relays: Vec<PublicKey>,
pub trusted_relay_settings: TrustedRelayConfig,
pub pii_config: Option<PiiConfig>,
pub grouping_config: Option<Value>,
pub filter_settings: ProjectFiltersConfig,
pub datascrubbing_settings: DataScrubbingConfig,
pub event_retention: Option<u16>,
pub downsampled_event_retention: Option<u16>,
pub retentions: RetentionsConfig,
pub trimming: TrimmingConfigs,
pub quotas: Vec<Quota>,
pub sampling: Option<ErrorBoundary<SamplingConfig>>,
pub measurements: Option<MeasurementsConfig>,
pub breakdowns_v2: Option<BreakdownsConfig>,
pub performance_score: Option<PerformanceScoreConfig>,
pub session_metrics: SessionMetricsConfig,
pub metric_extraction: ErrorBoundary<MetricExtractionConfig>,
pub metric_conditional_tagging: Vec<TaggingRule>,
pub features: FeatureSet,
pub tx_name_rules: Vec<TransactionNameRule>,
pub tx_name_ready: bool,
pub span_description_rules: Option<Vec<SpanDescriptionRule>>,
}Expand description
Dynamic, per-DSN configuration passed down from Sentry.
Fields
allowed_domains: Vec<String>URLs that are permitted for cross original JavaScript requests.
trusted_relays: Vec<PublicKey>List of relay public keys that are permitted to access this project.
trusted_relay_settings: TrustedRelayConfigConfiguration for trusted Relay behaviour.
pii_config: Option<PiiConfig>Configuration for PII stripping.
grouping_config: Option<Value>The grouping configuration.
filter_settings: ProjectFiltersConfigConfiguration for filter rules.
datascrubbing_settings: DataScrubbingConfigConfiguration for data scrubbers.
event_retention: Option<u16>Maximum event retention for the organization.
downsampled_event_retention: Option<u16>Maximum sampled event retention for the organization.
retentions: RetentionsConfigRetention settings for different products.
trimming: TrimmingConfigsTrimming settings for different products.
quotas: Vec<Quota>Usage quotas for this project.
sampling: Option<ErrorBoundary<SamplingConfig>>Configuration for sampling traces, if not present there will be no sampling.
measurements: Option<MeasurementsConfig>Configuration for measurements.
NOTE: do not access directly, use [relay_event_normalization::CombinedMeasurementsConfig].
breakdowns_v2: Option<BreakdownsConfig>Configuration for operation breakdown. Will be emitted only if present.
performance_score: Option<PerformanceScoreConfig>Configuration for performance score calculations. Will be emitted only if present.
session_metrics: SessionMetricsConfigConfiguration for extracting metrics from sessions.
metric_extraction: ErrorBoundary<MetricExtractionConfig>Configuration for generic metrics extraction from all data categories.
metric_conditional_tagging: Vec<TaggingRule>Rules for applying metrics tags depending on the event’s content.
features: FeatureSetExposable features enabled for this project.
tx_name_rules: Vec<TransactionNameRule>Transaction renaming rules.
tx_name_ready: boolWhether or not a project is ready to mark all URL transactions as “sanitized”.
span_description_rules: Option<Vec<SpanDescriptionRule>>Span description renaming rules.
These are currently not used by Relay, and only here to be forwarded to old relays that might still need them.
Implementations